Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/applicant.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/applicant.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/applicant.py	(revision 7819)
@@ -27,8 +27,8 @@
 from hurry.workflow.interfaces import IWorkflowInfo, IWorkflowState
 from waeup.kofa.app import University
-from waeup.kofa.image import KOFAImageFile
+from waeup.kofa.image import KofaImageFile
 from waeup.kofa.imagestorage import DefaultFileStoreHandler
 from waeup.kofa.interfaces import (
-    IObjectHistory, IFileStoreHandler, IFileStoreNameChooser, IKOFAUtils,
+    IObjectHistory, IFileStoreHandler, IFileStoreNameChooser, IKofaUtils,
     IExtFileStore, IPDF, IUserAccount)
 from waeup.kofa.students.vocabularies import RegNumNotInSource
@@ -76,5 +76,5 @@
     def display_fullname(self):
         middlename = getattr(self, 'middlename', None)
-        kofa_utils = getUtility(IKOFAUtils)
+        kofa_utils = getUtility(IKofaUtils)
         return kofa_utils.fullname(self.firstname, self.lastname, middlename)
 
@@ -291,5 +291,5 @@
             ApplicantImageStoreHandler, self).createFile(
             store, root,  filename, file_id, file)
-        return file, path, KOFAImageFile(
+        return file, path, KofaImageFile(
             file_obj.filename, file_obj.data)
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/interfaces.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/interfaces.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/interfaces.py	(revision 7819)
@@ -29,5 +29,5 @@
 from waeup.kofa.schema import TextLineChoice
 from waeup.kofa.interfaces import (
-    IKOFAObject, year_range, validate_email, academic_sessions_vocab)
+    IKofaObject, year_range, validate_email, academic_sessions_vocab)
 from waeup.kofa.interfaces import MessageFactory as _
 from waeup.kofa.payments.interfaces import IOnlinePayment
@@ -178,10 +178,10 @@
     pass
 
-class IApplicantsRoot(IKOFAObject, IContainer):
+class IApplicantsRoot(IKofaObject, IContainer):
     """A container for university applicants containers.
     """
     pass
 
-class IApplicantsContainer(IKOFAObject):
+class IApplicantsContainer(IKofaObject):
     """An applicants container contains university applicants.
 
@@ -352,5 +352,5 @@
     'provider'].order =  IApplicantsContainer['provider'].order
 
-class IApplicantBaseData(IKOFAObject):
+class IApplicantBaseData(IKofaObject):
     """The data for an applicant.
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/pdf.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/pdf.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/pdf.py	(revision 7819)
@@ -34,5 +34,5 @@
 from waeup.kofa.applicants.interfaces import IApplicant
 from waeup.kofa.browser import DEFAULT_PASSPORT_IMAGE_PATH
-from waeup.kofa.interfaces import IExtFileStore, IPDF, IKOFAUtils
+from waeup.kofa.interfaces import IExtFileStore, IPDF, IKofaUtils
 from waeup.kofa.interfaces import MessageFactory as _
 
@@ -54,5 +54,5 @@
     def title(self):
         container_title = self.context.__parent__.title
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         ar_translation = translate(_('Application Record'),
             'waeup.kofa', target_language=portal_language)
@@ -107,5 +107,5 @@
         if dept is None:
             return data
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         dp_translation = translate(_('Department:'),
             'waeup.kofa', target_language=portal_language)
@@ -145,5 +145,5 @@
             pdf.setAuthor('%s (%s)' % (view.request.principal.title,
                 view.request.principal.id))
-        pdf.setCreator('KOFA')
+        pdf.setCreator('Kofa')
         width, height = A4
         style = getSampleStyleSheet()
@@ -171,5 +171,5 @@
         # Render widget fields
         widgets = self._setUpWidgets()
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         for widget in widgets: # self.widgets:
             f_label = '<font size=12>%s</font>:' % translate(
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/root.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/root.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/root.py	(revision 7819)
@@ -23,5 +23,5 @@
 from hurry.query.interfaces import IQuery
 from zope.component import getUtility
-from waeup.kofa.interfaces import IKOFAPluggable
+from waeup.kofa.interfaces import IKofaPluggable
 from waeup.kofa.applicants.interfaces import IApplicantsRoot
 from waeup.kofa.utils.logger import Logger
@@ -46,5 +46,5 @@
 
 class ApplicantsPlugin(grok.GlobalUtility):
-    """A KOFAPlugin that creates an applicants root in portal.
+    """A KofaPlugin that creates an applicants root in portal.
 
     This plugin should be called by a typical
@@ -53,8 +53,8 @@
     the main site configuration.
 
-    Implements :class:`waeup.kofa.interfaces.IKOFAPluggable`
+    Implements :class:`waeup.kofa.interfaces.IKofaPluggable`
     """
     grok.name('applicants')
-    grok.implements(IKOFAPluggable)
+    grok.implements(IKofaPluggable)
     log_prefix = 'ApplicantsPlugin'
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_applicant.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_applicant.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/tests/test_applicant.py	(revision 7819)
@@ -26,5 +26,5 @@
 from zope.interface import verify, implements
 from zope.location.interfaces import ILocation
-from waeup.kofa.image.interfaces import IKOFAImageFile
+from waeup.kofa.image.interfaces import IKofaImageFile
 from waeup.kofa.imagestorage import DefaultStorage
 from waeup.kofa.interfaces import IFileStoreHandler, IFileStoreNameChooser
@@ -38,5 +38,5 @@
 class FakeImageLocation(object):
     implements(ILocation)
-    adapts(IKOFAImageFile)
+    adapts(IKofaImageFile)
     def __init__(self, context):
         pass
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/workflow.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/workflow.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/workflow.py	(revision 7819)
@@ -22,7 +22,7 @@
 from hurry.workflow.interfaces import IWorkflowState, IWorkflowTransitionEvent
 from waeup.kofa.applicants.interfaces import IApplicantBaseData
-from waeup.kofa.interfaces import IObjectHistory, IKOFAWorkflowInfo, IKOFAUtils
+from waeup.kofa.interfaces import IObjectHistory, IKofaWorkflowInfo, IKofaUtils
 from waeup.kofa.interfaces import MessageFactory as _
-from waeup.kofa.workflow import KOFAWorkflow, KOFAWorkflowInfo
+from waeup.kofa.workflow import KofaWorkflow, KofaWorkflowInfo
 
 INITIALIZED = 'initialized'
@@ -137,5 +137,5 @@
     )
 
-application_workflow = KOFAWorkflow(APPLICATION_TRANSITIONS)
+application_workflow = KofaWorkflow(APPLICATION_TRANSITIONS)
 
 class ApplicationWorkflowState(WorkflowState, grok.Adapter):
@@ -148,9 +148,9 @@
     state_id = 'wf.application.id'
 
-class ApplicationWorkflowInfo(KOFAWorkflowInfo, grok.Adapter):
+class ApplicationWorkflowInfo(KofaWorkflowInfo, grok.Adapter):
     """Adapter to adapt Applicant objects to workflow info objects.
     """
     grok.context(IApplicantBaseData)
-    grok.provides(IKOFAWorkflowInfo)
+    grok.provides(IKofaWorkflowInfo)
 
     def __init__(self, context):

Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/browser.py	(revision 7819)
@@ -35,5 +35,5 @@
 from waeup.kofa.applicants.workflow import INITIALIZED, STARTED, PAID, SUBMITTED
 from waeup.kofa.browser import (
-    KOFAPage, KOFAEditFormPage, KOFAAddFormPage, KOFADisplayFormPage,
+    KofaPage, KofaEditFormPage, KofaAddFormPage, KofaDisplayFormPage,
     DEFAULT_PASSPORT_IMAGE_PATH)
 from waeup.kofa.browser.interfaces import ICaptchaManager
@@ -44,6 +44,6 @@
 from waeup.kofa.browser.resources import datepicker, tabs, datatable, warning
 from waeup.kofa.interfaces import (
-    IKOFAObject, ILocalRolesAssignable, IExtFileStore, IPDF,
-    IFileStoreNameChooser, IPasswordValidator, IUserAccount, IKOFAUtils)
+    IKofaObject, ILocalRolesAssignable, IExtFileStore, IPDF,
+    IFileStoreNameChooser, IPasswordValidator, IUserAccount, IKofaUtils)
 from waeup.kofa.interfaces import MessageFactory as _
 from waeup.kofa.permissions import get_users_with_local_roles
@@ -56,7 +56,7 @@
 from waeup.kofa.widgets.restwidget import ReSTDisplayWidget
 
-grok.context(IKOFAObject) # Make IKOFAObject the default context
-
-class ApplicantsRootPage(KOFAPage):
+grok.context(IKofaObject) # Make IKofaObject the default context
+
+class ApplicantsRootPage(KofaPage):
     grok.context(IApplicantsRoot)
     grok.name('index')
@@ -70,5 +70,5 @@
         return
 
-class ApplicantsRootManageFormPage(KOFAEditFormPage):
+class ApplicantsRootManageFormPage(KofaEditFormPage):
     grok.context(IApplicantsRoot)
     grok.name('manage')
@@ -141,5 +141,5 @@
         return del_local_roles(self,3,**data)
 
-class ApplicantsContainerAddFormPage(KOFAAddFormPage):
+class ApplicantsContainerAddFormPage(KofaAddFormPage):
     grok.context(IApplicantsRoot)
     grok.require('waeup.manageApplication')
@@ -215,5 +215,5 @@
         return self.context.p_id
 
-class ApplicantsContainerPage(KOFADisplayFormPage):
+class ApplicantsContainerPage(KofaDisplayFormPage):
     """The standard view for regular applicant containers.
     """
@@ -232,5 +232,5 @@
     @property
     def introduction(self):
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         lang = self.request.cookies.get('kofa.language', portal_language)
         html = self.context.description_dict.get(lang,'')
@@ -246,5 +246,5 @@
         return "%s" % self.context.title
 
-class ApplicantsContainerManageFormPage(KOFAEditFormPage):
+class ApplicantsContainerManageFormPage(KofaEditFormPage):
     grok.context(IApplicantsContainer)
     grok.name('manage')
@@ -349,5 +349,5 @@
         return del_local_roles(self,3,**data)
 
-class ApplicantAddFormPage(KOFAAddFormPage):
+class ApplicantAddFormPage(KofaAddFormPage):
     """Add-form to add an applicant.
     """
@@ -372,5 +372,5 @@
         return
 
-class ApplicantDisplayFormPage(KOFADisplayFormPage):
+class ApplicantDisplayFormPage(KofaDisplayFormPage):
     grok.context(IApplicant)
     grok.name('index')
@@ -484,5 +484,5 @@
 
 
-class OnlinePaymentDisplayFormPage(KOFADisplayFormPage):
+class OnlinePaymentDisplayFormPage(KofaDisplayFormPage):
     """ Page to view an online payment ticket
     """
@@ -547,5 +547,5 @@
     @property
     def title(self):
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         return translate(_('Payment Data'), 'waeup.kofa',
             target_language=portal_language)
@@ -553,5 +553,5 @@
     @property
     def label(self):
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         return translate(_('Online Payment Receipt'),
             'waeup.kofa', target_language=portal_language) \
@@ -582,5 +582,5 @@
     #@property
     #def label(self):
-    #    portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+    #    portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
     #    container_title = self.context.__parent__.title
     #    label = translate('Application Record',
@@ -638,5 +638,5 @@
     return True
 
-class ApplicantManageFormPage(KOFAEditFormPage):
+class ApplicantManageFormPage(KofaEditFormPage):
     """A full edit view for applicant data.
     """
@@ -883,5 +883,5 @@
         return image
 
-class ApplicantRegistrationPage(KOFAAddFormPage):
+class ApplicantRegistrationPage(KofaAddFormPage):
     """Captcha'd registration page for applicants.
     """
@@ -926,5 +926,5 @@
         self.applyData(applicant, **data)
         self.context.addApplicant(applicant)
-        kofa_utils = getUtility(IKOFAUtils)
+        kofa_utils = getUtility(IKofaUtils)
         password = kofa_utils.genPassword()
         IUserAccount(applicant).setPassword(password)
@@ -941,5 +941,5 @@
         return
 
-class ApplicantRegistrationEmailSent(KOFAPage):
+class ApplicantRegistrationEmailSent(KofaPage):
     """Landing page after successful registration.
     """
Index: main/waeup.kofa/trunk/src/waeup/kofa/applicants/viewlets.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/applicants/viewlets.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/applicants/viewlets.py	(revision 7819)
@@ -18,5 +18,5 @@
 import grok
 from hurry.workflow.interfaces import IWorkflowState
-from waeup.kofa.interfaces import IKOFAObject
+from waeup.kofa.interfaces import IKofaObject
 from waeup.kofa.students.viewlets import PrimaryStudentNavTab
 from waeup.kofa.browser.viewlets import ManageActionButton, PrimaryNavTab
@@ -32,5 +32,5 @@
 from waeup.kofa.interfaces import MessageFactory as _
 
-grok.context(IKOFAObject) # Make IKOFAObject the default context
+grok.context(IKofaObject) # Make IKofaObject the default context
 grok.templatedir('browser_templates')
 
@@ -38,5 +38,5 @@
     """Applicants tab in primary navigation.
     """
-    grok.context(IKOFAObject)
+    grok.context(IKofaObject)
     grok.order(3)
     grok.require('waeup.viewApplicantsTab')